Store

Struct Store 

pub struct Store {
    pub card_opts: CardOptions,
    /* private fields */
}

Fields

card_opts: CardOptions

Implementations

Source

impl Store

pub fn open(path: &Path, card_opts: CardOptions) -> Result<Self>

pub fn reload_if_replaced(&mut self) -> Result<bool>

Reopen when the index file was atomically replaced by a rebuild.

pub fn config(&self) -> &Config

pub fn resolve(&self, query: &str, limit: usize) -> Result<Vec<GroupMatch>>

Group key or name to candidates, best tier first.

pub fn search(&self, req: &SearchRequest) -> Result<SearchOutcome>

pub fn get(&self, id: &str) -> Result<Option<Value>>

Full stored record, exactly as ingested.

pub fn describe(&self, top: usize) -> Result<Description>